@@ -6,11 +6,11 @@ use Import::Into ();
 use Module::Runtime ();
 use Scalar::Util ();
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 our @CARP_NOT = 'Mojolicious::Plugin::Log::Any';
 
-requires qw(on unsubscribe);
+requires 'on';
 
 sub attach_logger {
   my ($self, $logger, $category) = @_;
@@ -69,11 +69,13 @@ sub attach_logger {
     };
   } elsif ($logger eq 'Log::Contextual' or "$logger"->isa('Log::Contextual')) {
     Module::Runtime::require_module("$logger");
-    "$logger"->import::into(ref($self), ':log');
+    Log::Contextual->VERSION('0.008001');
+    my %functions = map { ($_ => "slog_$_") } qw(debug info warn error fatal);
+    "$logger"->import::into(ref($self), values %functions);
     $do_log = sub {
       my ($self, $level, @msg) = @_;
       my $formatted = "[$level] " . join "\n", @msg;
-      $self->can("slog_$level")->($formatted);
+      $self->can($functions{$level})->($formatted);
     };
   } else {
     Carp::croak "Unsupported logger class $logger";
